@@ -227,8 +227,7 @@ class CenterIndices(IndexedFreeAbelianMonoid):
         ret = set(gens)
         ret.update([self.prod(gens), gens[1] * gens[3]**4, gens[1]**4 * gens[2]**3])
         # Sort the output for uniqueness
-        ret = sorted(ret, key=lambda m: (self.degree(m), m.to_word_list()))
-        return ret
+        return sorted(ret, key=lambda m: (self.degree(m), m.to_word_list()))
 
     def degree(self, m):
         r"""
@@ -312,7 +311,7 @@ class CenterIndices(IndexedFreeAbelianMonoid):
                 continue
             M = matrix(R, [[v[s] for v in ad] for s in supp])
             ker = M.right_kernel_matrix()
-            vecs = [self._reduce(UEA.linear_combination((vecs[i], c) for i, c in kv.iteritems()))
+            vecs = [self._reduce(UEA.linear_combination((vecs[i], c) for i, c in kv.items()))
                     for kv in ker.rows()]
 
         # Lastly, update the appropriate data
@@ -475,8 +474,7 @@ class CenterUEA(CombinatorialFreeModule):
 
         sage: # needs sage.combinat
         sage: L = LieAlgebra(QQ, 2, step=4); L
-        Free Nilpotent Lie algebra on 8 generators
-         (X_1, X_2, X_12, X_112, X_122, X_1112, X_1122, X_1222) over Rational Field
+        Free Nilpotent Lie algebra of rank 2 and step 4 over Rational Field
         sage: U = L.pbw_basis()
         sage: Z = U.center()
         sage: it = iter(Z.basis())
