@@ -10,7 +10,7 @@ appropriate dimension.
 
 EXAMPLES::
 
-    sage: from sage.modules.matrix_morphism import MatrixMorphism, is_MatrixMorphism
+    sage: from sage.modules.matrix_morphism import MatrixMorphism
     sage: V = QQ^3
     sage: T = End(V)
     sage: M = MatrixSpace(QQ,3)
@@ -54,35 +54,11 @@ import sage.categories.morphism
 import sage.categories.homset
 from sage.categories.finite_dimensional_modules_with_basis import FiniteDimensionalModulesWithBasis
 from sage.categories.modules_with_basis import ModulesWithBasis
-from sage.structure.all import Sequence, parent
+from sage.structure.sequence import Sequence
+from sage.structure.element import parent
 from sage.structure.richcmp import richcmp, op_NE, op_EQ
 
 
-def is_MatrixMorphism(x):
-    """
-    Return ``True`` if x is a Matrix morphism of free modules.
-
-    This function is deprecated.
-
-    EXAMPLES::
-
-        sage: V = ZZ^2; phi = V.hom([3*V.0, 2*V.1])
-        sage: sage.modules.matrix_morphism.is_MatrixMorphism(phi)
-        doctest:warning...
-        DeprecationWarning: is_MatrixMorphism is deprecated;
-        use isinstance(..., MatrixMorphism_abstract) or categories instead
-        See https://github.com/sagemath/sage/issues/37731 for details.
-        True
-        sage: sage.modules.matrix_morphism.is_MatrixMorphism(3)
-        False
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(37731,
-                "is_MatrixMorphism is deprecated; "
-                "use isinstance(..., MatrixMorphism_abstract) or categories instead")
-    return isinstance(x, MatrixMorphism_abstract)
-
-
 class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
 
     # Copy in methods that delegate to self.matrix.
